using System;
using Server;
using System.Collections;
using Server.Targeting;

namespace Server.Items
{

	public class CorkScrew : Item, IUsesRemaining
	{
		private int m_UsesRemaining;

		[CommandProperty( AccessLevel.GameMaster )]
		public int UsesRemaining
		{
			get { return m_UsesRemaining; }
			set { m_UsesRemaining = value; InvalidateProperties(); }
		}

		public bool ShowUsesRemaining{ get{ return true; } set{} }
		
		[Constructable]
		public CorkScrew() : base( 0x1029 )
		{
	     	Name = "a corkscrew";
	     	Weight = 1.0;
	     	UsesRemaining = 50;
		}
		
		public override void GetProperties( ObjectPropertyList list )
		{
			base.GetProperties( list );
		
			list.Add( 1060584, m_UsesRemaining.ToString() ); // uses remaining: ~1_val~
		}
		
		public override void OnDoubleClick( Mobile from )
		{
			
			if ( !IsChildOf( from.Backpack ) )
			{
				from.SendLocalizedMessage( 1042001 ); // That must be in your pack for you to use it.
			}
			else if ( UsesRemaining <= 0 )
				from.SendLocalizedMessage( 1019073 ); // This item is out of charges.
			else
			{
				from.SendMessage( "Select the potion, potion keg, or container of potions to empty." );
				from.Target = new ScrewTarget( this );
			}
		}
		
		public CorkScrew( Serial serial ) : base( serial )
		{
		}
		
		public override void Serialize( GenericWriter writer )
		{
			base.Serialize( writer );

			writer.Write( (int) 0 ); // version
			writer.Write( (int) m_UsesRemaining );
		}

		public override void Deserialize( GenericReader reader )
		{
			base.Deserialize( reader );

			int version = reader.ReadInt();
			m_UsesRemaining = reader.ReadInt();
		}
		
		public static void ConsumeCharge( Mobile from, CorkScrew screw )
		{
			screw.UsesRemaining -= 1;

			if ( screw.UsesRemaining == 0 )
			{
				from.SendLocalizedMessage( 1044038 ); // You have worn out your tool!.
				screw.Delete();
			}
		}
	
	private class ScrewTarget : Target
	{
		CorkScrew m_screw;
		
		public ScrewTarget( CorkScrew screw ) : base( 2, false, TargetFlags.None )
		{
			m_screw = screw;
		}
		protected override void OnTarget( Mobile from, object target ) 
		{
			if ( target is PotionKeg )
			{
				PotionKeg pk = (PotionKeg)target;
				
				if( pk.RootParent != from )
				{
					from.SendMessage( "The potion keg must be in your backpack in order to empty!" );
					return;
				}
				
				if ( pk.Held != 0 )
				{
					pk.Held = 0;
					ConsumeCharge( from, m_screw );
					from.SendMessage( "You empty out the potion keg." );
					from.PlaySound( 0x241 ); // liquid.wav
				}
				else
				{
					from.SendMessage( "That potion keg is already empty." );
				}
			}
			else if ( target is BasePotion )
			{
				BasePotion p = (BasePotion)target;

				if( p.RootParent != from )
				{
					from.SendMessage( "The potion must be in your backpack in order to empty!" );
					return;
				}
				
				if ( p.Parent != null )
					((BaseContainer)p.Parent).DropAndStack( new Bottle() );
				p.Delete();
				from.SendMessage( "You have dumped the potion out, and put the empty bottle in your pack." );
				ConsumeCharge( from, m_screw );
				from.PlaySound( 0x241 ); // liquid.wav
			}
			else if ( target is Container )
			{
				Container c = (Container)target;

				if( c.RootParent != from )
				{
					from.SendMessage( "The container of potions must be in your backpack in order to empty!" );
					return;
				}
				
				if ( c.FindItemByType( typeof (BasePotion) ) != null )
				{
					foreach( BasePotion potion in c.FindItemsByType( typeof( BasePotion), true ) )
					{
						if ( potion.Parent != null )
							((BaseContainer)potion.Parent).DropAndStack( new Bottle() );
						potion.Delete();
						ConsumeCharge( from, m_screw );
						if ( m_screw.UsesRemaining == 0 )
							break;
					}
					from.PlaySound( 0x241 ); // liquid.wav
					from.SendMessage( "The potions have been emptied." );
				}
				else 
					from.SendMessage( "That container holds no potions!" );
			}
			else
				from.SendMessage( "You may only use this on a full potion or a container with potions in it!" );
		}
	}
  }
}
